package Qt::Gui::QTextItem;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTextItem
# file     : QtGui/qpaintengine.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QTextItem

=head1 PUBLIC METHODS

=over

=item  qreal ascent()

=item  qreal descent()

=item  QFont font()

=item  QFlags<QTextItem::RenderFlag> renderFlags()

=item  QString text()

=item  qreal width()


=back

=head1 ENUM VALUES

=over

=item RightToLeft

=item Overline

=item Underline

=item StrikeOut

=item Dummy


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
